==> hledger-web-1.3-11-i686.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.3
id: hledger-web-1.3-GNgj9XcjMl44w8kA4SID1q
key: hledger-web-1.3-GNgj9XcjMl44w8kA4SID1q
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: 76f5f638c475d0428d856cd699aab73e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.3-GNgj9XcjMl44w8kA4SID1q
depends:
    HUnit-1.6.0.0-60ZLMGxowdyCquCGGOoE3I base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    clientsession-0.9.1.2-9kKpoTVy5mACXNsbrHrhsB
    cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    conduit-extra-1.1.16-5YILVd78SGn9wwYaAO3g7W
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    filepath-1.4.1.1 hjsmin-0.2.0.2-KVIZEO0GpxR4sKyr7sGnCY
    hledger-1.3-31Aai1UqtITJI6DvcC964Z
    hledger-lib-1.3-92jrkUykEU38AWlukeydoO
    http-client-0.5.7.0-8CqgjLtDELe98Oo6kiK06v
    http-conduit-2.2.3.2-C1rDIbSB5cpFgoxSqkp3Nr
    json-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I
    megaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    shakespeare-2.0.13-7tkYqZznbwm6X0y1el8pnL template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-extra-3.0.20.0-BxVwY0rS5Ws6LtyxYJkIIh
    wai-handler-launch-3.0.2.2-3TLoZqAxqvfKeMlRhka7ns
    warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
    yaml-0.8.23.3-8FJZhPKX9fmLLFoNaNncOM
    yesod-1.4.5-2iEbqTnTbJt2j5Ai7CFcei
    yesod-core-1.4.35-ECdYF3cZgyb9Ing5BpGGKz
    yesod-form-1.4.12-IcthS9MzU4v17XxQtjBBYV
    yesod-static-1.5.3-15aWFaUMvWrActriHKUlLG
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.3-14-i686.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.3
id: hledger-web-1.3-8WrPAoEAcrL9bX9kVIofDG
key: hledger-web-1.3-8WrPAoEAcrL9bX9kVIofDG
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: ff1a4553db0b34d885174cc2db0e01a8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.3-8WrPAoEAcrL9bX9kVIofDG
depends:
    HUnit-1.6.0.0-60ZLMGxowdyCquCGGOoE3I base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    clientsession-0.9.1.2-9kKpoTVy5mACXNsbrHrhsB
    cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    conduit-extra-1.1.16-5YILVd78SGn9wwYaAO3g7W
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    filepath-1.4.1.1 hjsmin-0.2.0.2-KVIZEO0GpxR4sKyr7sGnCY
    hledger-1.3-31Aai1UqtITJI6DvcC964Z
    hledger-lib-1.3-92jrkUykEU38AWlukeydoO
    http-client-0.5.7.0-8CqgjLtDELe98Oo6kiK06v
    http-conduit-2.2.3.2-CRy4tYu0ljJKEchcyy6apj
    json-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I
    megaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    shakespeare-2.0.13-7tkYqZznbwm6X0y1el8pnL template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-extra-3.0.20.0-BxVwY0rS5Ws6LtyxYJkIIh
    wai-handler-launch-3.0.2.2-3TLoZqAxqvfKeMlRhka7ns
    warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
    yaml-0.8.23.3-8FJZhPKX9fmLLFoNaNncOM
    yesod-1.4.5-KOeoYi9gSa9Elay9TMrJjW
    yesod-core-1.4.35.1-Kx8p5Lynpe24mDlJNTuKbn
    yesod-form-1.4.13-4OFhPWFuhsTEtWTKmK3tkj
    yesod-static-1.5.3.1-AZ1ZcZybLSDJ8WyMEBZxOS
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
